<?php
/*
Plugin Name: WooCommerce Schema Type (WST)
Plugin URI: https://upinserp.com
Description: Un plugin que aplica automaticamente el schema type adecuado para SEO en tiendas WooCommerce con previsualización de Google Shopping. ✅ Página de Inicio: WebPage + CollectionPage ✅ Tienda: CollectionPage ✅ Productos: Product ✅ Reseñas: Review ✅ Ofertas: Offer ✅ Valoraciones: AggregateRating ✅ Listas de Productos: ItemList
Version: 1.3
Author: Upinserp
Author URI: https://upinserp.com
License: GPL2
Text Domain: wst
Domain Path: /languages
*/

function wst_load_textdomain() {
    load_plugin_textdomain('wst', false, dirname(plugin_basename(__FILE__)) . '/languages/');
}
add_action('plugins_loaded', 'wst_load_textdomain');

add_action('admin_menu', 'wst_add_admin_menu');

function wst_add_admin_menu() {
    add_menu_page(
        'Schema Type',
        'Schema Type',
        'manage_options',
        'wst-schema-type',
        'wst_admin_page',
        'dashicons-admin-settings',
        20
    );
}

add_filter('plugin_action_links_' . plugin_basename(__FILE__), 'wst_add_settings_link');

function wst_add_settings_link($links) {
    $settings_link = '<a href="admin.php?page=wst-schema-type">' . __('Settings', 'wst') . '</a>';
    array_unshift($links, $settings_link);
    return $links;
}

add_action('wp_head', 'wst_add_homepage_schema');

function wst_add_homepage_schema() {
    if (is_front_page()) {
        $schema = array(
            "@context" => "https://schema.org",
            "@type" => "WebPage",
            "name" => get_bloginfo('name'),
            "description" => get_bloginfo('description'),
            "url" => home_url(),
            "mainEntity" => array(
                "@type" => "CollectionPage",
                "name" => __("Nuestra Colección de Productos", 'wst'),
                "description" => __("Explora nuestra amplia gama de productos disponibles.", 'wst'),
                "url" => home_url(),
                "hasPart" => array()
            )
        );

        $products = wc_get_products(array(
            'status' => 'publish',
            'limit' => 5,
            'visibility' => 'featured'
        ));

        foreach ($products as $product) {
            $schema['mainEntity']['hasPart'][] = array(
                "@type" => "Product",
                "name" => $product->get_name(),
                "url" => get_permalink($product->get_id()),
                "image" => wp_get_attachment_url($product->get_image_id()),
                "description" => wp_trim_words($product->get_short_description() ?: $product->get_description(), 20),
                "offers" => array(
                    "@type" => "Offer",
                    "price" => $product->get_price(),
                    "priceCurrency" => get_woocommerce_currency(),
                    "availability" => $product->is_in_stock() ? "https://schema.org/InStock" : "https://schema.org/OutOfStock"
                )
            );
        }

        echo '<script type="application/ld+json">' . wp_json_encode($schema, JSON_PRETTY_PRINT | JSON_UNESCAPED_SLASHES) . '</script>';
    }
}

add_action('wp_head', 'wst_add_shop_page_schema');

function wst_add_shop_page_schema() {
    if (is_shop()) {
        $schema = array(
            "@context" => "https://schema.org",
            "@type" => "CollectionPage",
            "name" => __("Nuestra Tienda", 'wst'),
            "description" => __("Explora todos nuestros productos disponibles.", 'wst'),
            "url" => get_permalink(wc_get_page_id('shop')),
            "hasPart" => array()
        );

        $products = wc_get_products(array(
            'status' => 'publish',
            'limit' => 10
        ));

        foreach ($products as $product) {
            $schema['hasPart'][] = array(
                "@type" => "Product",
                "name" => $product->get_name(),
                "url" => get_permalink($product->get_id()),
                "image" => wp_get_attachment_url($product->get_image_id()),
                "description" => wp_trim_words($product->get_short_description() ?: $product->get_description(), 20),
                "offers" => array(
                    "@type" => "Offer",
                    "price" => $product->get_price(),
                    "priceCurrency" => get_woocommerce_currency(),
                    "availability" => $product->is_in_stock() ? "https://schema.org/InStock" : "https://schema.org/OutOfStock"
                )
            );
        }

        echo '<script type="application/ld+json">' . wp_json_encode($schema, JSON_PRETTY_PRINT | JSON_UNESCAPED_SLASHES) . '</script>';
    }
}

function wst_admin_page() {
    ?>
    <div class="wrap">
        <div id="wst-banner" class="wst-banner">
            <p>
            ⚡<a href="https://webanner.net" target="_blank"><?php _e('Anúncia tus webs y tiendas E-Commerce y consigue cicks, impresiones y ventas GRATIS!', 'wst'); ?></a>⚡
            </p>
            <button id="wst-banner-close" class="wst-banner-close">✖</button>
        </div>
        <div class="wst-header">
            <div class="wst-header-image">
                <img src="<?php echo plugins_url('/WST.png', __FILE__); ?>" alt="<?php esc_attr_e('WooCommerce Schema Type', 'wst'); ?>">
            </div>
            <div class="wst-header-content">
                <p class="wst-description">
                    <strong><?php _e('WST está diseñado para optimizar el SEO del marcado schema de tu tienda WooCommerce', 'wst'); ?></strong></br> <?php _e('Este plugin selecciona automáticamente el "Type" adecuado para cada sección de tu tienda.', 'wst'); ?>
                </p>
            </div>
        </div>
        <div class="wst-container">
            <div class="wst-status">
                <div class="wst-status-box wst-yoast-compatible">
                    <span class="dashicons dashicons-yes"></span>
                    <p><?php _e('Compatibilidad con Yoast SEO activada.', 'wst'); ?></p>
                </div>
                <div class="wst-status-box wst-schema-valid">
                    <span class="dashicons dashicons-yes"></span>
                    <p><?php _e('Marcado Schema correcto para WooCommerce.', 'wst'); ?></p>
                </div>
                <div class="wst-status-box wst-google-ready">
                    <span class="dashicons dashicons-google"></span>
                    <p><?php _e('Tu sitio está optimizado para Google Shopping.', 'wst'); ?></p>
                </div>
            </div>
            <div class="wst-preview">
                <h2><?php _e('Previsualización de producto en Google Shopping', 'wst'); ?></h2>
                <div class="wst-preview-content">
                    <?php echo wst_get_random_product_preview(); ?>
                </div>
            </div>
            <div class="wst-schema-messages">
                <h2><?php _e('Schema Type optimizado para SEO en WooCommerce', 'wst'); ?></h2>
				<div class="wst-message">
                    <span class="dashicons dashicons-admin-home"></span>
                    <p><strong><?php _e('Página de Inicio:', 'wst'); ?></strong> <?php _e('Schema "WebPage + CollectionPage" aplicado automáticamente por defecto.', 'wst'); ?></p>
                </div>
                <div class="wst-message">
                    <span class="dashicons dashicons-cart"></span>
                    <p><strong><?php _e('Página de la Tienda:', 'wst'); ?></strong> <?php _e('Schema "CollectionPage" aplicado automáticamente por defecto.', 'wst'); ?></p>
                </div>
                <div class="wst-message">
                    <span class="dashicons dashicons-admin-post"></span>
                    <p><strong><?php _e('Página de Producto:', 'wst'); ?></strong> <?php _e('Schema "Product" aplicado automáticamente por defecto.', 'wst'); ?></p>
                </div>
                <div class="wst-message">
                    <span class="dashicons dashicons-format-chat"></span>
                    <p><strong><?php _e('Reseñas:', 'wst'); ?></strong> <?php _e('Schema "Review" aplicado automáticamente por defecto.', 'wst'); ?></p>
                </div>
                <div class="wst-message">
                    <span class="dashicons dashicons-tag"></span>
                    <p><strong><?php _e('Ofertas:', 'wst'); ?></strong> <?php _e('Schema "Offer" aplicado automáticamente por defecto.', 'wst'); ?></p>
                </div>
                <div class="wst-message">
                    <span class="dashicons dashicons-star-filled"></span>
                    <p><strong><?php _e('Valoraciones:', 'wst'); ?></strong> <?php _e('Schema "AggregateRating" aplicado automáticamente por defecto.', 'wst'); ?></p>
                </div>
                <div class="wst-message">
                    <span class="dashicons dashicons-admin-page"></span>
                    <p><strong><?php _e('Lista de Productos:', 'wst'); ?></strong> <?php _e('Schema "ItemList" aplicado automáticamente por defecto.', 'wst'); ?></p>
                </div>
            </div>
        </div>
    </div>
    <style>
        .wst-header {
            display: flex;
            align-items: center;
            gap: 20px;
            background: #fff;
            padding: 20px;
            border-radius: 8px;
            box-shadow: 0 2px 5px rgba(0, 0, 0, 0.1);
            margin-bottom: 20px;
        }
        .wst-header-image img {
            max-width: 250px;
            height: auto;
            border-radius: 8px;
        }
        .wst-header-content {
            flex: 1;
        }
        .wst-header h1 {
            margin: 0 0 10px;
            font-size: 24px;
            color: #1a0dab;
        }
        .wst-description {
            font-size: 14px;
            color: #545454;
            line-height: 1.6;
        }
        .wst-features {
            margin: 10px 0 0;
            padding-left: 20px;
        }
        .wst-features li {
            margin-bottom: 5px;
            font-size: 14px;
            color: #545454;
        }
        .wst-features .dashicons {
            color: #4caf50;
            margin-right: 5px;
        }
        .wst-container {
            display: flex;
            flex-direction: column;
            gap: 20px;
        }
        .wst-status {
            display: flex;
            gap: 10px;
            margin-bottom: 20px;
        }
        .wst-status-box {
            flex: 1;
            background: #f9f9f9;
            padding: 15px;
            border-radius: 8px;
            text-align: center;
            box-shadow: 0 2px 5px rgba(0, 0, 0, 0.1);
        }
        .wst-status-box .dashicons {
            font-size: 24px;
            color: #4caf50;
        }
        .wst-status-box p {
            margin: 5px 0 0;
            font-size: 14px;
        }
        .wst-preview {
            background: #fff;
            padding: 20px;
            border-radius: 8px;
            box-shadow: 0 2px 5px rgba(0, 0, 0, 0.1);
        }
        .wst-preview-content {
            margin-top: 10px;
        }
        .wst-preview-content .google-preview {
            font-family: Arial, sans-serif;
            border: 1px solid #ddd;
            padding: 10px;
            border-radius: 8px;
            display: flex;
            align-items: center;
            gap: 20px;
        }
        .wst-preview-content .google-image img {
            max-width: 100px;
            height: auto;
            border-radius: 8px;
        }
        .wst-preview-content .google-details {
            flex: 1;
        }
        .wst-preview-content .google-title {
            font-size: 18px;
            color: #1a0dab;
            margin: 0;
        }
        .wst-preview-content .google-url {
            font-size: 14px;
            color: #006621;
            margin: 5px 0;
        }
        .wst-preview-content .google-description {
            font-size: 14px;
            color: #545454;
            margin: 5px 0;
        }
        .wst-preview-content .google-rating {
            font-size: 14px;
            color: #ff9900;
            margin: 5px 0;
        }
        .wst-preview-content .google-price {
            font-size: 16px;
            color: #000;
            margin: 5px 0;
        }
        .wst-preview-content .google-stock {
            font-size: 16px;
            color: #006621;
            margin: 5px 0;
        }
        .wst-schema-messages {
            background: #fff;
            padding: 20px;
            border-radius: 8px;
            box-shadow: 0 2px 5px rgba(0, 0, 0, 0.1);
        }
        .wst-message {
            display: flex;
            align-items: center;
            gap: 10px;
            padding: 10px;
            background: #f9f9f9;
            border-radius: 8px;
            box-shadow: 0 2px 5px rgba(0, 0, 0, 0.1);
            margin-bottom: 10px;
        }
        .wst-message .dashicons {
            font-size: 24px;
            color: #4caf50;
        }
        .wst-message p {
            margin: 0;
            font-size: 14px;
        }
        .wst-banner {
            background: #fff3cd;
            padding: 10px;
            border-radius: 8px;
            box-shadow: 0 2px 5px rgba(0, 0, 0, 0.1);
            display: flex;
            justify-content: space-between;
            align-items: center;
            margin-bottom: 20px;
        }
        .wst-banner p {
            margin: 0;
            font-size: 14px;
            color: #856404;
        }
        .wst-banner a {
            color: #856404;
            text-decoration: underline;
        }
        .wst-banner-close {
            background: none;
            border: none;
            font-size: 16px;
            cursor: pointer;
            color: #856404;
        }
    </style>
    <script>
        document.addEventListener('DOMContentLoaded', function() {
            const closeBtn = document.getElementById('wst-banner-close');
            closeBtn.addEventListener('click', function() {
                const banner = document.getElementById('wst-banner');
                banner.style.display = 'none';
            });
        });
    </script>
    <?php
}

function wst_get_random_product_preview() {
    $args = array(
        'status' => 'publish',
        'limit' => 1,
        'orderby' => 'rand'
    );
    $products = wc_get_products($args);

    if (!empty($products)) {
        $product = $products[0];
        $image = wp_get_attachment_url($product->get_image_id());
        $rating = $product->get_average_rating();
        $rating_count = $product->get_rating_count();
        $price = wc_price($product->get_price());
        $description = wp_trim_words($product->get_short_description() ?: $product->get_description(), 20);
        $stock_status = $product->get_stock_status();
        $stock_text = ($stock_status === 'instock') ? __('En stock', 'wst') : __('Agotado', 'wst');

        ob_start();
        ?>
        <div class="google-preview">
            <div class="google-image">
                <img src="<?php echo esc_url($image); ?>" alt="<?php echo esc_attr($product->get_name()); ?>">
            </div>
            <div class="google-details">
                <h3 class="google-title"><?php echo esc_html($product->get_name()); ?></h3>
                <div class="google-url"><?php echo esc_url(get_permalink($product->get_id())); ?></div>
                <div class="google-description"><?php echo esc_html($description); ?></div>
                <div class="google-rating">
                    <?php echo str_repeat('⭐', round($rating)); ?> (<?php echo esc_html($rating); ?>/5 <?php _e('de', 'wst'); ?> <?php echo esc_html($rating_count); ?> <?php _e('reseñas', 'wst'); ?>)
                </div>
                <div class="google-price"><?php echo $price; ?></div>
                <div class="google-stock"><?php _e('Disponibilidad', 'wst'); ?>: <?php echo esc_html($stock_text); ?></div>
            </div>
        </div>
        <?php
        return ob_get_clean();
    }

    return '<p>' . __('No se encontraron productos.', 'wst') . '</p>';
}
?>